@@ -1,7 +1,7 @@
 package WWW::Google::Contacts;
 
 BEGIN {
-    $WWW::Google::Contacts::VERSION = '0.18';
+    $WWW::Google::Contacts::VERSION = '0.19';
 }
 
 # ABSTRACT: Google Contacts Data API
@@ -265,14 +265,16 @@ __END__
 
     my $google = WWW::Google::Contacts->new( username => "your.username", password => "your.password" );
 
+    # Create a new contact
     my $contact = $google->new_contact;
     $contact->full_name("Emmett Brown");
     $contact->name_prefix("Dr");
     $contact->email('doctor@timetravel.org');
     $contact->hobby("Time travel");
     $contact->jot([ "Went back in time", "Went forward in time", "Became blacksmith" ]),
-    $contact->create;
+    $contact->create;  # save it to the server
 
+    # Now search for the given name, and read the jots
     my @contacts = $google->contacts->search({ given_name => "Emmett" });
     foreach my $c ( @contacts ) {
         print "Got the following jots about the good doctor\n";
@@ -283,12 +285,24 @@ __END__
         $c->delete;
     }
 
-
+    # Print the names of all groups
     my $groups = $google->groups;
     while ( my $group = $groups->next ) {
         print "Title = " . $group->title . "\n";
     }
 
+    # Add the contact to existing group 'Movie stars' and to a new group 'Back to the future'
+    my $new_group = $google->new_group({ title => "Back to the future" });
+    $new_group->create;  # create on server
+
+    my @groups = $google->groups->search({ title => "Movie stars" });
+    my $movie_stars_group = shift @groups;
+
+    $contact->add_group_membership( $new_group );
+    $contact->add_group_membership( $movie_stars_group );
+    $contact->update;
+
+
 =head1 DESCRIPTION
 
 This module implements 'Google Contacts Data API' according L<http://code.google.com/apis/contacts/docs/3.0/developers_guide_protocol.html>
